aboutsummaryrefslogtreecommitdiffstats
path: root/dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java
diff options
context:
space:
mode:
Diffstat (limited to 'dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java')
-rw-r--r--dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java22
1 files changed, 11 insertions, 11 deletions
diff --git a/dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java b/dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java
index e4a884e..f0a4705 100644
--- a/dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java
+++ b/dcae-controller-service-cdap/dcae-controller-service-cdap-model/src/main/xcore-gen/org/openecomp/dcae/controller/service/cdap/CdapDeployAppStep.java
@@ -12,7 +12,7 @@ package org.openecomp.dcae.controller.service.cdap;
* The following features are supported:
* </p>
* <ul>
- * <li>{@link org.openecomp.dcae.controller.service.cdap.CdapDeployAppStep#getJarfile <em>Jarfile</em>}</li>
+ * <li>{@link org.openecomp.dcae.controller.service.cdap.CdapDeployAppStep#getJarFile <em>Jar File</em>}</li>
* </ul>
*
* @see org.openecomp.dcae.controller.service.cdap.CdapPackage#getCdapDeployAppStep()
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
*/
public interface CdapDeployAppStep extends CdapStep {
/**
* Returns the value of the '<em><b>Jarfile</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Jarfile</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Jarfile</em>' attribute.
* @see #setJarfile(String)
* @see org.openecomp.dcae.controller.service.cdap.CdapPackage#getCdapDeployAppStep_Jarfile()
* @model unique="false"
* @generated
*/
- String getJarfile();
+ String getJarFile();
/**
* Sets the value of the '{@link org.openecomp.dcae.controller.service.cdap.CdapDeployAppStep#getJarfile <em>Jarfile</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Jarfile</em>' attribute.
* @see #getJarfile()
* @generated
*/
- void setJarfile(String value);
+ void setJarFile(String value);
} // CdapDeployAppStep
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
public interface CdapDeployAppStep extends CdapStep {
/**
- * Returns the value of the '<em><b>Jarfile</b></em>' attribute.
+ * Returns the value of the '<em><b>Jar File</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Jarfile</em>' attribute isn't clear,
+ * If the meaning of the '<em>Jar File</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Jarfile</em>' attribute.
- * @see #setJarfile(String)
- * @see org.openecomp.dcae.controller.service.cdap.CdapPackage#getCdapDeployAppStep_Jarfile()
+ * @return the value of the '<em>Jar File</em>' attribute.
+ * @see #setJarFile(String)
+ * @see org.openecomp.dcae.controller.service.cdap.CdapPackage#getCdapDeployAppStep_JarFile()
* @model unique="false"
* @generated
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
/**
- * Sets the value of the '{@link org.openecomp.dcae.controller.service.cdap.CdapDeployAppStep#getJarfile <em>Jarfile</em>}' attribute.
+ * Sets the value of the '{@link org.openecomp.dcae.controller.service.cdap.CdapDeployAppStep#getJarFile <em>Jar File</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -21,29 +21,29 @@ package org.openecomp.dcae.controller.service.cdap;
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Jarfile</em>' attribute.
- * @see #getJarfile()
+ * @param value the new value of the '<em>Jar File</em>' attribute.
+ * @see #getJarFile()
* @generated
*/